/**
 * Model helper utilities.
 *
 * Note: Presets have been removed in favor of using OpenCode's native config.
 * Default models are baked into agent definitions.
 * Users can override via opencode.json.
 */
/**
 * Check if a model ID is from OpenAI.
 */
export declare function isOpenAIModel(model: string): boolean;
/**
 * Check if a model ID is from Anthropic.
 */
export declare function isAnthropicModel(model: string): boolean;
//# sourceMappingURL=presets.d.ts.map