import type { WindowState } from './types';
/**
 * Query the current tmux window state
 * Returns information about all panes in the current window
 */
export declare function queryWindowState(sourcePaneId: string): Promise<WindowState | null>;
//# sourceMappingURL=state-query.d.ts.map