import type { PluginInput } from '@opencode-ai/plugin';
import type { CoderConfig } from '../../types';
export interface SessionHooks {
    onMessage: (input: unknown, output: unknown) => Promise<void>;
}
export declare function createSessionHooks(_ctx: PluginInput, _config: CoderConfig): SessionHooks;
//# sourceMappingURL=session.d.ts.map